# Front page

This page lists available data collections, and allows new ones to be created.

To **view an existing collection**, click on the corresponding link in the 'id' column.

To **create a new collection**, enter a short collection identifier value (consisting of letters, digits and underscores) and a short label describing the collection into the boxes, then click on the 'New' button.  To **remove a collection**, select the check box in the rightmost column, and click on 'Remove selected'  Options to create and/or remove collections are displayed only for logged-in users.

If not logged in, the top menu bar will show a 'Login' item at its rioght had end: click on this to log in.  If already logged in, the menu bar will instead show 'User' with the name of the logged in user, and 'Logout'.  Click on the 'User' item to show information about the logged in user, and on 'Logout' to log out.
